#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2022-09-20
# File  : wato/cisco_cellular_lte
#

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    TextAscii,
    MonitoringState,
    FixedValue,
    ListOfStrings,
    ListOf,
    Integer,
    Tuple,
    DropdownChoice,
)

from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithItem,
    rulespec_registry,
    RulespecGroupCheckParametersNetworking,
    RulespecGroupCheckParametersDiscovery,
    HostRulespec,
)


def _parameter_valuespec_cisco_cellular_lte():
    return Dictionary(
        elements=[
            ('rsrp_levels_lower',
             Tuple(
                 title=_('Lower levels for RSRP'),
                 help=_('Lower levels for RSRP (Reference Signal Received Power) in dBm'),
                 elements=[
                     Integer(title=_('Warning below'), default_value=-100, unit=_('dBm')),
                     Integer(title=_('Critical below'), default_value=-115, unit=_('dBm')),
                 ])),
            ('rsrq_levels_lower',
             Tuple(
                 title=_('Lower levels for RSRQ'),
                 help=_('Lower levels for RSRQ (Reference Signal Received Quality) in dB'),
                 elements=[
                     Integer(title=_('Warning below'), default_value=-8, unit=_('dB')),
                     Integer(title=_('Critical below'), default_value=-15, unit=_('dB')),
                 ])),
            ('rssi_levels_lower',
             Tuple(
                 title=_('Lower levels for RSSI'),
                 help=_('Lower levels for RSSI (Received Signal Strength Indicator) in dBm'),
                 elements=[
                     Integer(title=_('Warning below'), default_value=-75, unit=_('dBm')),
                     Integer(title=_('Critical below'), default_value=-85, unit=_('dBm')),
                 ])),
            ('roaming_state',
             MonitoringState(
                 title=_('Monitoring state if the device is roaming'),
                 help=_('Monitoring state if the device is roaming. Default is WARN.'),
                 default_value=1,
             )),
            ('no_profile_state',
             MonitoringState(
                 title=_('Monitoring state if no GSM/LTE profile configured'),
                 help=_('Monitoring state if no GSM/LTE  profile is configured. Default is WARN.'),
                 default_value=1,
             )),
            ('connection_state',
             MonitoringState(
                 title=_('Monitoring state if the device is not connected'),
                 help=_('Monitoring state if the device is not connected. Default is CRIT.'),
                 default_value=1,
             )),
            ('modem_not_up_state',
             MonitoringState(
                 title=_('Monitoring state if the modem is not up'),
                 help=_('Monitoring state if the the modem is not up. Default is CRIT.'),
                 default_value=1,
             )),
            ('modem_not_online_state',
             MonitoringState(
                 title=_('Monitoring state if the modem is not online'),
                 help=_('Monitoring state if the the modem is not online. Default is CRIT.'),
                 default_value=1,
             )),
        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name='cisco_cellular_lte',
        group=RulespecGroupCheckParametersNetworking,
        match_type='dict',
        parameter_valuespec=_parameter_valuespec_cisco_cellular_lte,
        title=lambda: _('Cisco cellular LTE'),
        item_spec=lambda: TextAscii(title=_('Item'), ),
    ))


def _valuespec_discovery_cisco_cellular_lte():
    return Dictionary(
            title=_('Cisco cellular LTE'),
            elements=[
                ('not_configured',
                 FixedValue(
                     True,
                     title=_('Discover not configured interfaces'),
                     help=_('If enabled the plugin will also discover cellular interfaces without a profile attached.'),
                     totext=_('')
                 )),
            ],
        )


rulespec_registry.register(
    HostRulespec(
        group=RulespecGroupCheckParametersDiscovery,
        match_type='dict',
        name='discovery_cisco_cellular_lte',
        valuespec=_valuespec_discovery_cisco_cellular_lte,
    ))
